@@ -32,14 +32,20 @@ class Config():
             self.data['botCertPassword'] = data['botCertPassword']
             self.data['botEmailAddress'] = data['botEmailAddress']
             self.data['p.12'] = self.data['botCertPath'] + '.p12'
+            self.data['authType'] = data['authType']
+            self.data['proxyURL'] = data['proxyURL']
+
         #take in .p12 certificate and parse through file to use for authentication
         #data['botCert_cert'] and data['botCert_key'] are passed as certificates upon authentication request
-        try:
-            logging.debug('p.12 --->  ' + self.data['p.12'])
-            crypt = Crypt(self.data['p.12'], self.data['botCertPassword'])
-            self.data['symphonyCertificate'], self.data['symphonyKey'] = crypt.p12parse()
+        if self.data['authType'] != 'RSA':
+            try:
+                logging.debug('p12 location ---> ' + self.data['p.12'])
+                crypt = Crypt(self.data['p.12'], self.data['botCertPassword'])
+                self.data['symphonyCertificate'], self.data['symphonyKey'] = crypt.p12parse()
 
+            except Exception as err:
+                print("Failed to load config file: %s" % err)
+                raise
 
-        except Exception as err:
-            print("Failed to load config file: %s" % err)
-            raise
+        else:
+            print('auth using RSA')
